#!/bin/bash
#pointing_finder.sh

OKITA="okita@192.168.161.90"

#Ubuntuのバグ対策。シリアルポートの設定を変更。
ssh $OKITA stty -F /dev/ttyUSB0 clocal


#望遠鏡の最大駆動速度を2degree/secに設定
rm -rf /program/LX200/command/lx200.sh
printf "#!/bin/bash\n
/program/LX200/meade :Sw2# -s 5\n" >> /program/LX200/command/lx200.sh

scp -rp /program/LX200/command/lx200.sh $OKITA:/program/LX200/command/.
ssh $OKITA sh /program/LX200/command/lx200.sh


#望遠鏡の駆動速度を2番目に遅く設定
rm -rf /program/LX200/command/lx200.sh
printf "#!/bin/bash\n
/program/LX200/meade :RC# -s 4\n" >> /program/LX200/command/lx200.sh

scp -rp /program/LX200/command/lx200.sh $OKITA:/program/LX200/command/.
ssh $OKITA sh /program/LX200/command/lx200.sh


#露出時間の読み込み
exposure=`awk '{print $1}' /program/LX200/exposure_finder/finder.exposure`
#回転角の読み込み
rotation=`awk '{print $1}' /program/LX200/rotation/rotation.angle`
#視野中心の定義の読み込み
xorg=`awk '{print $1}' /program/LX200/pointing_finder/finder.original`
yorg=`awk '{print $2}' /program/LX200/pointing_finder/finder.original`


j=1
while [ $j -le 5 ] #視野内での位置を測定し、Ra,Decモーターを駆動して視野移動、これを5回繰り返す
do


    #(1)撮像を5回繰り返す
    rm -rf /program/LX200/pointing_finder/*.fits
    i=1
    while [ $i -le 5 ]
    do
        i=`printf "%03d" $i`
	rm -rf /program/LX200/command/finder_ccd.sh
	printf "#!/bin/bash\n
night_exposure -t $exposure -s on -b 1 -o /program/LX200/pointing_finder/pointing$i.fits" >> /program/LX200/command/finder_ccd.sh
	sh /program/LX200/command/finder_ccd.sh

        i=`expr $i + 1`
    done


    #(2)sextractorで星の情報を抽出し、awkで最輝星の(x,y)を抽出
    rm -rf /program/LX200/sextractor/image_stat.dat
    i=1
    while [ $i -le 5 ]
    do
        i=`printf "%03d" $i`
	cd /program/LX200/sextractor/
        sex /program/LX200/pointing_finder/pointing$i.fits > /dev/null
        cd /program/LX200/
        awk -f /program/LX200/sextractor/image_stat.awk /program/LX200/sextractor/test.cat >> /program/LX200/sextractor/image_stat.dat
        i=`expr $i + 1`
    done
    rm -rf /program/LX200/sextractor/test.cat


    #(3)awkで最輝星の(x,y)のメジアンを計算する
    rm -rf /program/LX200/pointing_finder/finder.current
    awk -f /program/LX200/pointing_finder/current_pointing.awk /program/LX200/sextractor/image_stat.dat > /program/LX200/pointing_finder/finder.current


    #(3)'gnuplotによる表示(省略可)
    cat /program/LX200/pointing_finder/finder.current >> /program/LX200/pointing_finder/finder.tmp
    gnuplot /program/LX200/pointing_finder/current_pointing.plt


    #(4)awkでoriginal.pointingとcurrent.pointingの差分を計算して望遠鏡に送るコマンドを作成
    #天体を検出しなかった場合は望遠鏡に送るコマンドは空白ファイルになる（望遠鏡は動かない）
    #この時にawkファイルで視野回転を補正する。
    #ちなみにここではまだ望遠鏡は動かさない
    rm -rf /program/LX200/command/lx200.sh
    paste /program/LX200/pointing_finder/finder.original /program/LX200/pointing_finder/finder.current > /program/LX200/pointing_finder/tmp2.pointing
    awk -f /program/LX200/pointing_finder/command_pointing.awk -v angle=$rotation /program/LX200/pointing_finder/tmp2.pointing > /program/LX200/command/lx200.sh
    rm -rf /program/LX200/pointing_finder/tmp2.pointing


    #(5)もしcurrent positionとoriginal positionの差が5pix^2=25未満の場合、ループを抜ける
    xcur=`awk '{print $1}' /program/LX200/pointing_finder/finder.current`
    ycur=`awk '{print $2}' /program/LX200/pointing_finder/finder.current`
    delta=`echo "scale=0; (($xorg-$xcur)^2+($yorg-$ycur)^2)/1" | bc`
    if test $delta -lt 25
    then

	#(8)sincコマンドを送る
        rm -rf /program/LX200/command/lx200.sh
        printf "#!/bin/bash\n
/program/LX200/meade :CM# -r 4\n" >> /program/LX200/command/lx200.sh

        scp -rp /program/LX200/command/lx200.sh $OKITA:/program/LX200/command/.
        ssh $OKITA sh /program/LX200/command/lx200.sh


	#(9)on pointの画像を撮像
	rm -rf /program/LX200/pointing_finder/on_pointing.finder.fits
	rm -rf /program/LX200/command/finder_ccd.sh
	printf "#!/bin/bash\n
night_exposure -t $exposure -s on -b 1 -o /program/LX200/pointing_finder/on_pointing.finder.fits\n" >> /program/LX200/command/finder_ccd.sh
	sh /program/LX200/command/finder_ccd.sh

        #gnulpot用のデータを削除
        rm -rf /program/LX200/pointing_finder/finder.tmp

        echo "POINTING FINDER SUCCESSFUL"
        exit 0

    else
        :
    fi




    #(7)計算した位置へ望遠鏡を動かす
    scp -rp /program/LX200/command/lx200.sh $OKITA:/program/LX200/command/.
    ssh $OKITA sh /program/LX200/command/lx200.sh

    j=`expr $j + 1`
done

#gnulpot用のデータを削除
rm -rf /program/LX200/pointing_finder/finder.tmp

echo "POINTING FINDER FAULT"
exit 1
